@@ -599,8 +599,17 @@ def get_author_and_location():
 def dev_menu(devname, action, owner):
     if os.getuid() != 0:
         warn('Expected UID 0 (root) for access')
-    author, location = get_author_and_location()
     hdd_dock = BaseStorageDevice.from_devname(devname)
+    try:
+        hdd_dock.led_normal()  # Clear existing LED pattern.
+        hdd_dock_dev_menu(hdd_dock, action, owner)
+    except Exception:
+        hdd_dock.led_failure()
+        raise
+
+
+def hdd_dock_dev_menu(hdd_dock, action, owner):
+    author, location = get_author_and_location()
     sys.stdout.write('\x1b]2;DOCKTOOL DISK BAY: {}\x07'.format(
         hdd_dock.docktool_bay_nr))
 
@@ -639,6 +648,10 @@ def dev_menu(devname, action, owner):
             hdd_dock.get_device_model(),
             hdd_dock.get_serial_number())
         assert hdd_id, 'HDD id not set after registration?'
+        # If one action is to print a health label also print a normal label
+        # for new registered disks.
+        if 'print-health-label' in action and 'print-label' not in action:
+            action.insert(0, 'print-label')
 
     registered_disk_actions(
         hdd_dock=hdd_dock, hdd_id=hdd_id,
