@@ -120,6 +120,9 @@ class BaseStorageDevice(object):
     def led_locate(self):
         self.led('locate')
 
+    def led_normal(self):
+        self.led('normal')
+
     def get_erase_methods(self):
         return [self.wipe_using_manual_methods]
 
